translate.filters.checks.OpenOfficeChecker

Package translate :: Package filters :: Module checks :: Class OpenOfficeChecker |
[hide private]
[frames] | no frames]

# Class OpenOfficeChecker

source code

Instance Methods | [hide private]
__init__(self, **kwargs) x.__init__(...) initializes x; see x.__class__.__doc__ for signature | source code
Inherited from `StandardChecker`: `accelerators`, `acronyms`, `blank`, `brackets`, `compendiumconflicts`, `credits`, `doublequoting`, `doublespacing`, `doublewords`, `emails`, `endpunc`, `endwhitespace`, `escapes`, `filepaths`, `functions`, `kdecomments`, `long`, `musttranslatewords`, `newlines`, `notranslatewords`, `numbers`, `options`, `printf`, `puncspacing`, `purepunc`, `sentencecount`, `short`, `simplecaps`, `simpleplurals`, `singlequoting`, `spellcheck`, `startcaps`, `startpunc`, `startwhitespace`, `tabs`, `unchanged`, `untranslated`, `urls`, `validchars`, `variables`, `xmltags` Inherited from `TranslationChecker`: `run_filters`, `run_test` Inherited from `UnitChecker`: `filteraccelerators`, `filteraccelerators_by_list`, `filtervariables`, `filterwordswithpunctuation`, `filterxml`, `getfilters`, `removevariables`, `setconfig`, `setsuggestionstore` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Class Variables | [hide private]
Inherited from `StandardChecker`: `preconditions`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, **kwargs) (Constructor) | source code
x.__init__(...) initializes x; see x.__class__.__doc__ for signature Overrides: object.__init__ (inherited documentation)